==> upgrade_risoluto-1_1_1_to_risoluto-1_2_0.tar.gz: upgrade_risoluto-1_1_1_to_risoluto-1_2_0/file/uploadviewer.php <==
<?php
/**
 * アップロードファイル表示画面クラス
 *
 * アップロードファイル表示画面を実現するためのクラス
 *
 * @package   risoluto
 * @author    Risoluto Developers
 * @license   http://opensource.org/licenses/bsd-license.php new BSD license
 * @copyright (C) 2008-2011 Risoluto Developers / All Rights Reserved.
 */

  /**
   * 基底クラス
   */
  require_once( "admin_site_base.inc" );
  /**
   * データベース操作クラス
   */
  require_once( RISOLUTO_FUNC . 'risoluto_db.php' );

  class uploadviewer extends admin_site_base
  {
    //------------------------------------------------------//
    // クラス変数定義
    //------------------------------------------------------//
    /**
     * データベース操作クラスインスタンスを保持する変数
     * @access private
     * @var    object
     */
    private $obj_db;
    /**
     * ユーティリティクラスインスタンスを保持する変数
     * @access private
     * @var    object
     */
    private $obj_conf;
    /**
     * 取得データを保持する変数
     * @access private
     * @var    object
     */
    private $gotDat;

    //------------------------------------------------------//
    // クラスメソッド定義
    //------------------------------------------------------//
    /**
     * コンストラクタメソッド
     *
     * コンストラクタメソッド
     *
     * @param     void なし
     * @return    void なし
     */
    public function __construct()
    {
    } // end of function:__construct()

    /**
     * クローンメソッド
     *
     * クローンメソッド
     *
     * @param     void なし
     * @return    void なし
     */
    public function __clone()
    {
    } // end of function:__clone()

    /**
     * modelメソッド（モデル）
     *
     * データ取得等のモデルに相当する部分の処理を行う
     *
     * @param     void なし
     * @return    boolean ファンクション実行結果（ true：正常終了 / false: 異常終了 ）
     */
    public function model()
    {
      // 必要なインスタンスを生成
      $this->obj_conf = new RisolutoConf();
      $this->obj_conf->parse( RISOLUTO_CONF . 'risoluto.ini' );



      //------------------------------------------------------------------------
      // パラメタチェック
      //------------------------------------------------------------------------
      if ( isset( $_GET[ 'id' ] ) and is_numeric( $_GET[ 'id' ] ) )
      {
        $tmp_entered = trim( strip_tags( $_GET[ 'id' ] ) );
      } // end of if



      // データベースに接続する
      // データベース操作クラスのインスタンスを生成する
      $this->obj_db = new RisoluteDb();



      //------------------------------------------------------------------------
      // 現在の最新IDを取得
      //------------------------------------------------------------------------

      // データベースに接続する
      if ( $this->obj_db->dbConnect( $this->obj_conf->get( 'DBS', 'DEFAULT_DSN' ) ) )
      {
        // SQL文を組み立てる
        $sql =<<<End_Of_SQL

              SELECT `upload`.`realname`
                   , `upload`.`mime`
                FROM `risoluto_t_upload` upload
               WHERE `upload`.`upload_id` = ?

End_Of_SQL;

        // パラメタも用意する
        $param = array(
                        $tmp_entered
                      );

        // SQLの実行に失敗した場合は、例外を投げる
        $tmp_result = $this->obj_db->dbGetRow( $sql, $param );
        if ( PEAR::isError( $tmp_result ) )
        {
          // 接続をクローズする
          $this->obj_db->dbDisConnect();
          throw new Exception( 'Select upload file information Failure' );
          return false;
        } // end of if
        // ヘッダを構成し、ファイルを出力する
        else
        {
          header( 'Content-type: ' . $tmp_result[ 'mime' ] );
          if ( isset( $_GET[ 'mode' ] ) and $_GET[ 'mode' ] == 'download' )
          {
            header( 'Content-Disposition: attachment; filename="' . $tmp_result[ 'realname' ] . '"' );
          } // end of if
          header( 'Content-Length: ' . filesize( realpath( RISOLUTO_UPLOAD . '/' . 'risoluto_uploaded_' . $tmp_entered ) ) );

          if ( ( $fp_dl = fopen( realpath( RISOLUTO_UPLOAD . '/' . 'risoluto_uploaded_' . $tmp_entered ), "r" ) ) )
          {
            while ( !feof( $fp_dl ) ) {
               echo fread( $fp_dl, 4096 );
               flush();
               ob_flush();
            }
            fclose( $fp_dl );
          }// end of if

        } // end of if
      } // end of if
      // データベースに接続できなかった場合は、例外を投げる
      else
      {
        throw new Exception( 'DB Connection Failure' );
        return false;
      } // end of else

      return true;
    } // end of function:model()

    /**
     * viewメソッド（モデル）
     *
     * テンプレート関連処理等のビューに相当する部分の処理を行う
     *
     * @param     void なし
     * @return    boolean ファンクション実行結果（ true：正常終了 / false: 異常終了 ）
     */
    public function view()
    {

      return true;

    } // end of function:view()

  } // end of class:uploadviewer

?>

==> upgrade_risoluto-1_3_0_to_risoluto-1_3_1.tar.gz: upgrade_risoluto-1_3_0_to_risoluto-1_3_1/file/uploadviewer.php <==
<?php
/**
 * アップロードファイル表示画面クラス
 *
 * アップロードファイル表示画面を実現するためのクラス
 *
 * @package   risoluto
 * @author    Risoluto Developers
 * @license   http://opensource.org/licenses/bsd-license.php new BSD license
 * @copyright (C) 2008-2011 Risoluto Developers / All Rights Reserved.
 */

  /**
   * 基底クラス
   */
  require_once( "admin_site_base.inc" );
  /**
   * データベース操作クラス
   */
  require_once( RISOLUTO_FUNC . 'risoluto_db.php' );

  class uploadviewer extends admin_site_base
  {
    //------------------------------------------------------//
    // クラス変数定義
    //------------------------------------------------------//
    /**
     * データベース操作クラスインスタンスを保持する変数
     * @access private
     * @var    object
     */
    private $obj_db;
    /**
     * ユーティリティクラスインスタンスを保持する変数
     * @access private
     * @var    object
     */
    private $obj_conf;
    /**
     * 取得データを保持する変数
     * @access private
     * @var    object
     */
    private $gotDat;

    //------------------------------------------------------//
    // クラスメソッド定義
    //------------------------------------------------------//
    /**
     * コンストラクタメソッド
     *
     * コンストラクタメソッド
     *
     * @param     void なし
     * @return    void なし
     */
    public function __construct()
    {
    } // end of function:__construct()

    /**
     * クローンメソッド
     *
     * クローンメソッド
     *
     * @param     void なし
     * @return    void なし
     */
    public function __clone()
    {
    } // end of function:__clone()

    /**
     * modelメソッド（モデル）
     *
     * データ取得等のモデルに相当する部分の処理を行う
     *
     * @param     void なし
     * @return    boolean ファンクション実行結果（ true：正常終了 / false: 異常終了 ）
     */
    public function model()
    {
      // 必要なインスタンスを生成
      $this->obj_conf = new RisolutoConf();
      $this->obj_conf->parse( RISOLUTO_CONF . 'risoluto.ini' );



      //------------------------------------------------------------------------
      // パラメタチェック
      //------------------------------------------------------------------------
      if ( isset( $_GET[ 'id' ] ) and is_numeric( $_GET[ 'id' ] ) )
      {
        $tmp_entered = trim( strip_tags( $_GET[ 'id' ] ) );
      } // end of if



      // データベースに接続する
      // データベース操作クラスのインスタンスを生成する
      $this->obj_db = new RisolutoDb();



      //------------------------------------------------------------------------
      // 現在の最新IDを取得
      //------------------------------------------------------------------------

      // データベースに接続する
      if ( $this->obj_db->dbConnect( $this->obj_conf->get( 'DBS', 'DEFAULT_DSN' ) ) )
      {
        // SQL文を組み立てる
        $sql =<<<End_Of_SQL

              SELECT `upload`.`realname`
                   , `upload`.`mime`
                FROM `risoluto_t_upload` upload
               WHERE `upload`.`upload_id` = ?

End_Of_SQL;

        // パラメタも用意する
        $param = array(
                        $tmp_entered
                      );

        // SQLの実行に失敗した場合は、例外を投げる
        $tmp_result = $this->obj_db->dbGetRow( $sql, $param );
        if ( PEAR::isError( $tmp_result ) )
        {
          // 接続をクローズする
          $this->obj_db->dbDisConnect();
          throw new Exception( 'Select upload file information Failure' );
          return false;
        } // end of if
        // ヘッダを構成し、ファイルを出力する
        else
        {
          header( 'Content-type: ' . $tmp_result[ 'mime' ] );
          if ( isset( $_GET[ 'mode' ] ) and $_GET[ 'mode' ] == 'download' )
          {
            header( 'Content-Disposition: attachment; filename="' . $tmp_result[ 'realname' ] . '"' );
          } // end of if
          header( 'Content-Length: ' . filesize( realpath( RISOLUTO_UPLOAD . '/' . 'risoluto_uploaded_' . $tmp_entered ) ) );

          if ( ( $fp_dl = fopen( realpath( RISOLUTO_UPLOAD . '/' . 'risoluto_uploaded_' . $tmp_entered ), "r" ) ) )
          {
            while ( !feof( $fp_dl ) )
            {
               echo fread( $fp_dl, 4096 );
               @flush();
               @ob_flush();
            } // end of while
            fclose( $fp_dl );
          }// end of if

        } // end of if
      } // end of if
      // データベースに接続できなかった場合は、例外を投げる
      else
      {
        throw new Exception( 'DB Connection Failure' );
        return false;
      } // end of else

      return true;
    } // end of function:model()

    /**
     * viewメソッド（モデル）
     *
     * テンプレート関連処理等のビューに相当する部分の処理を行う
     *
     * @param     void なし
     * @return    boolean ファンクション実行結果（ true：正常終了 / false: 異常終了 ）
     */
    public function view()
    {

      return true;

    } // end of function:view()

  } // end of class:uploadviewer

?>
